@@ -3,16 +3,14 @@
 ## names outputs?
 
 
-# library(BCEA)
-library(dplyr)
-library(reshape2)
-
-
-load(test_path("ce.RData"))
+# library(dplyr)
+# library(reshape2)
 
 
 test_that("input errors", {
   
+  load(test_path("ce.RData"))
+  
   expect_dims_error <- function(x, y) {
     expect_error(
       bcea(x, y,
@@ -62,6 +60,8 @@ test_that("input errors", {
 
 test_that("basic return", {
   
+  load(test_path("ce.RData"))
+  
   res <- 
     bcea(e = eff,
          c = cost)
@@ -187,6 +187,8 @@ test_that("jags, bugs, stan methods", {
 
 test_that("k and wtp arguments", {
   
+  load(test_path("ce.RData"))
+  
   m <- bcea(eff, cost, plot = FALSE)
   
   expect_equal(m$Kmax, 50000)
@@ -202,6 +204,9 @@ test_that("k and wtp arguments", {
 })
 
 test_that("using e and c still works", {
+  
+  load(test_path("ce.RData"))
+  
   e <- eff
   c <- cost
   bcea_res <- bcea(eff = eff, cost = cost)
@@ -213,6 +218,8 @@ test_that("using e and c still works", {
 
 test_that("named reference", {
   
+  load(test_path("ce.RData"))
+  
   expect_equal(bcea(eff, cost, ref = 1, interventions = c("a", "b")),
                bcea(eff, cost, ref = "a", interventions = c("a", "b")))
   
