@@ -1,14 +1,13 @@
 
-# library(BCEA)
-library(dplyr)
-library(reshape2)
-
-
-load("ce.RData")
+# library(dplyr)
+# library(reshape2)
 
+##TODO:
 
 test_that("compute_U", {
   
+  load(test_path("ce.RData"))
+  
   # single wtp
   
   # c_tmp <- matrix(c(0, 0, 100, 10), nrow = 2)
